@@ -20,6 +20,7 @@
  */
 
 #include "config.h"
+#define _GNU_SOURCE /* for strchrnul */
 
 #include <string.h>
 #include <stdlib.h>
@@ -126,7 +127,8 @@ open_url (GtkWindow *parent,
   else
     screen = gdk_screen_get_default ();
 
-  return gtk_show_uri (screen, uri, user_time, error);
+  return terminal_util_uri_is_allowed (uri, error) &&
+         gtk_show_uri (screen, uri, user_time, error);
 }
 
 void
@@ -1104,3 +1106,84 @@ terminal_util_number_info (const char *str)
 
   return g_strdup_printf(hex ? "0x%2$s = %1$s%3$s" : "%s = 0x%s%s", decstr, hexstr, magnitudestr);
 }
+
+/**
+ * terminal_util_is_uri_allowed:
+ * @uri: The URI to check
+ * @error: a #GError that is returned in case of errors
+ *
+ * Checks if gnome-terminal should attempt to handle the given URI.
+ * Currently URIs of "file://some-other-host/..." are refused because
+ * GIO (e.g. gtk_show_uri()) silently strips off the remote hostname
+ * and opens the local counterpart which is incorrect and misleading.
+ *
+ * Returns: TRUE if gnome-terminal should attempt to handle the URI,
+ *   FALSE if it should refuse to handle.
+ */
+gboolean
+terminal_util_uri_is_allowed (const char *uri,
+                              GError **error)
+{
+  gs_free char *filename;
+  gs_free char *hostname;
+
+  filename = g_filename_from_uri (uri, &hostname, NULL);
+  if (filename != NULL &&
+      hostname != NULL &&
+      hostname[0] != '\0' &&
+      g_ascii_strcasecmp (hostname, "localhost") != 0 &&
+      g_ascii_strcasecmp (hostname, g_get_host_name()) != 0) {
+    g_set_error_literal (error,
+                         G_IO_ERROR,
+                         G_IO_ERROR_NOT_SUPPORTED,
+                         _("“file” scheme with remote hostname not supported"));
+    return FALSE;
+  }
+  return TRUE;
+}
+
+/**
+ * terminal_util_hyperlink_uri_label:
+ * @uri: a URI
+ *
+ * Formats @uri to be displayed in a tooltip.
+ * Performs URI-decoding and converts IDN hostname to UTF-8.
+ *
+ * Returns: (transfer full): The human readable URI as plain text
+ */
+char *terminal_util_hyperlink_uri_label (const char *uri)
+{
+  char *unesc = NULL;
+  gboolean replace_hostname;
+
+  if (uri == NULL)
+    return NULL;
+
+  unesc = g_uri_unescape_string(uri, NULL);
+  if (unesc == NULL)
+    unesc = g_strdup(uri);
+
+  if (g_ascii_strncasecmp(unesc, "ftp://", 6) == 0 ||
+      g_ascii_strncasecmp(unesc, "http://", 7) == 0 ||
+      g_ascii_strncasecmp(unesc, "https://", 8) == 0) {
+    gs_free char *unidn = NULL;
+    char *hostname = strchr(unesc, '/') + 2;
+    char *hostname_end = strchrnul(hostname, '/');
+    char save = *hostname_end;
+    *hostname_end = '\0';
+    unidn = g_hostname_to_unicode(hostname);
+    replace_hostname = unidn != NULL && g_ascii_strcasecmp(unidn, hostname) != 0;
+    *hostname_end = save;
+    if (replace_hostname) {
+      char *new_unesc = g_strdup_printf("%.*s%s%s",
+                                        (int) (hostname - unesc),
+                                        unesc,
+                                        unidn,
+                                        hostname_end);
+      g_free(unesc);
+      unesc = new_unesc;
+    }
+  }
+
+  return unesc;
+}
